@@ -397,7 +397,7 @@ class TestUploadCommand:
             repo_id=DUMMY_MODEL_ID,
             repo_type="model",
             exist_ok=True,
-            private=False,
+            private=None,
             space_sdk=None,
         )
         api.upload_folder.assert_called_once_with(
@@ -483,7 +483,7 @@ class TestUploadCommand:
             allow_patterns=["*.json", "*.yaml"],
             ignore_patterns=["*.log", "*.txt"],
             path_in_repo="data/",
-            private=False,
+            private=None,
             every=5,
             hf_api=api,
         )
@@ -706,7 +706,7 @@ class TestUploadImpl:
             repo_id="my-dataset",
             repo_type="dataset",
             exist_ok=True,
-            private=False,
+            private=None,
             space_sdk=None,
         )
         api.upload_file.assert_called_once_with(
@@ -1330,6 +1330,11 @@ class TestInferenceEndpointsCommands:
             namespace=None,
             token=None,
             task=None,
+            min_replica=1,
+            max_replica=1,
+            scaling_metric=None,
+            scaling_threshold=None,
+            scale_to_zero_timeout=None,
         )
         assert '"name": "hub"' in result.stdout
 
@@ -1404,6 +1409,8 @@ class TestInferenceEndpointsCommands:
             max_replica=None,
             scale_to_zero_timeout=None,
             token=None,
+            scaling_metric=None,
+            scaling_threshold=None,
         )
         assert '"name": "updated"' in result.stdout
 
