@@ -299,7 +299,7 @@ def test_sync_vs_async_signatures() -> None:
 
 @pytest.mark.asyncio
 async def test_async_generate_timeout_error(monkeypatch: pytest.MonkeyPatch) -> None:
-    def _mock_aiohttp_client_timeout(*args, **kwargs):
+    async def _mock_client_post(*args, **kwargs):
         raise asyncio.TimeoutError
 
     def mock_check_supported_task(*args, **kwargs):
@@ -308,9 +308,10 @@ async def test_async_generate_timeout_error(monkeypatch: pytest.MonkeyPatch) ->
     monkeypatch.setattr(
         "huggingface_hub.inference._providers.hf_inference._check_supported_task", mock_check_supported_task
     )
-    monkeypatch.setattr("aiohttp.ClientSession.post", _mock_aiohttp_client_timeout)
+    client = AsyncInferenceClient(timeout=1)
+    client._async_client = Mock(post=_mock_client_post)
     with pytest.raises(InferenceTimeoutError):
-        await AsyncInferenceClient(timeout=1).text_generation("test")
+        await client.text_generation("test")
 
 
 class CustomException(Exception):
@@ -415,32 +416,3 @@ async def test_use_async_with_inference_client():
         async with AsyncInferenceClient():
             pass
     mock_close.assert_called_once()
-
-
-@pytest.mark.asyncio
-@patch("aiohttp.ClientSession._request")
-async def test_client_responses_correctly_closed(request_mock: Mock) -> None:
-    """
-    Regression test for #2521.
-    Async client must close the ClientResponse objects when exiting the async context manager.
-    Fixed by closing the response objects when the session is closed.
-
-    See https://github.com/huggingface/huggingface_hub/issues/2521.
-    """
-    async with AsyncInferenceClient() as client:
-        session = client._get_client_session()
-        response1 = await session.get("http://this-is-a-fake-url.com")
-        response2 = await session.post("http://this-is-a-fake-url.com", json={})
-
-    # Response objects are closed when the AsyncInferenceClient is closed
-    response1.close.assert_called_once()
-    response2.close.assert_called_once()
-
-
-@pytest.mark.asyncio
-async def test_warns_if_client_deleted_with_opened_sessions():
-    client = AsyncInferenceClient()
-    session = client._get_client_session()
-    with pytest.warns(UserWarning):
-        client.__del__()
-    await session.close()
